#####
cuFJC
#####

|build| |pyversions| |pypi| |license| |zenodo|

The Python package for the composite uFJC (cuFJC) model.

************
Installation
************

This package can be installed using ``pip`` via the `Python Package Index <https://pypi.org/project/cufjc/>`_ (PyPI),

::

    pip install cufjc

Alternatively, a branch can be directly installed using

::

    pip install git+https://github.com/jasonmulderrig/cuFJC.git@<branch-name>

or after cloning a branch, moving to the main project directory (where the setup and configuration files are located), and executing ``pip install -e .`` for an editable installation or ``pip install .`` for a standard installation.

***********
Information
***********

- `License <https://github.com/jasonmulderrig/cuFJC/LICENSE>`__
- `Releases <https://github.com/jasonmulderrig/cuFJC/releases>`__
- `Repository <https://github.com/jasonmulderrig/cuFJC>`__

********
Citation
********

\Jason Mulderrig, Brandon Talamini, and Nikolaos Bouklas, ``cufjc``: the Python package for the composite uFJC (cuFJC) model, `Zenodo (2024) <https://doi.org/10.5281/zenodo.10871017>`_.

\Jason Mulderrig, Brandon Talamini, and Nikolaos Bouklas, A statistical mechanics framework for polymer chain scission, based on the concepts of distorted bond potential and asymptotic matching, `Journal of the Mechanics and Physics of Solids 174, 105244 (2023) <https://www.sciencedirect.com/science/article/pii/S0022509623000480>`_.

..
    Badges ========================================================================

.. |build| image:: https://img.shields.io/github/checks-status/jasonmulderrig/cuFJC/main?label=GitHub&logo=github
    :target: https://github.com/jasonmulderrig/cuFJC

.. |pyversions| image:: https://img.shields.io/pypi/pyversions/cufjc.svg?logo=python&logoColor=FBE072&color=4B8BBE&label=Python
    :target: https://pypi.org/project/cufjc/

.. |pypi| image:: https://img.shields.io/pypi/v/cufjc?logo=pypi&logoColor=FBE072&label=PyPI&color=4B8BBE
    :target: https://pypi.org/project/cufjc/

.. |license| image:: https://img.shields.io/github/license/jasonmulderrig/cuFJC?label=License
    :target: https://github.com/jasonmulderrig/cuFJC/LICENSE

.. |zenodo| image:: https://zenodo.org/badge/DOI/10.5281/zenodo.10871017.svg
   :target: https://doi.org/10.5281/zenodo.10871017